@@ -32,11 +32,7 @@ class CellvoyConnector(IlastikConnector):
     def _open_image_file(self, image_nr):
 
         img_names = self.names_all_channels[image_nr]
-        pixels = np.array([[io.imread(img_name)] for img_name in img_names])
-        pixels = np.expand_dims(pixels, axis=0)
-        return pixels
-
-    def image_dimensions(self, image_nr):
-        dims = np.array(self. _open_image_file(image_nr)[0].shape)
-        dims[[-1, -2]] = dims[[-2, -1]]
-        return dims
+        pixels = np.stack([io.imread(img_name) for img_name in img_names], axis = -1)
+        if len(pixels.shape) == 3:
+            pixels = np.expand_dims(pixels, axis=0)
+        return pixels
\ No newline at end of file
